FxDirectory

Struct FxDirectory 

pub struct FxDirectory { /* private fields */ }

Implementations

Source

impl FxDirectory

pub fn directory(&self) -> &Directory<FxVolume>

pub fn volume(&self) -> &Arc<FxVolume>

pub fn store(&self) -> &ObjectStore

pub fn is_deleted(&self) -> bool

pub fn set_deleted(&self)

As per fscrypt, a user cannot link an unencrypted file into an encrypted directory nor can a user link an encrypted file into a directory encrypted with a different key. Appropriate locks must be held by the caller.