pub enum FlushType {
Sync,
LastChance,
Background,
}Expand description
The type of the flush to reflect the caller intent.
Variants
Sync
The default sync type. This flushes everything it can and if there are errors then it stops early and will try to flush the rest later.
LastChance
When the file is being closed and the flush needs to clean everything up. If there are errors then it will still return all resources even if that means data loss.
Background
Flushing some pages in the background because there are a lot of dirty pages to push. May not get all dirty pages.