FxFile

Struct FxFile 

pub struct FxFile { /* private fields */ }
FxFile represents an open connection to a file.

Implementations

Source

impl FxFile

pub fn new(handle: DataObjectHandle<FxVolume>) -> Arc<Self>

Creates a new regular FxFile.

pub async fn create_connection_async( this: OpenedNode<FxFile>, scope: ExecutionScope, flags: impl ProtocolsExt, object_request: ObjectRequestRef<'_>, ) -> Result<(), Status>

Creates a new connection on the given scope. May take a read lock on the object.

pub fn open_as_temporary(self: Arc<Self>) -> OpenedNode<dyn FxNode>

Open the file as a temporary. The file must have just been created with no other open counts.

pub fn mark_as_permanent(&self)

Mark the state as permanent (to be used when the file is currently marked as temporary).

pub fn is_verified_file(&self) -> bool

pub fn handle(&self) -> &PagedObjectHandle

pub fn into_opened_node(self: Arc<Self>) -> Option<OpenedNode<FxFile>>

If this instance has not been marked to be purged, returns an OpenedNode instance. If marked for purging, returns None.

pub async fn flush( this: &OpenedNode<FxFile>, last_chance: bool, ) -> Result<(), Error>

Persists any unflushed data to disk.

Flush may be triggered as a background task so this requires an OpenedNode to ensure that we don’t accidentally try to flush a file handle that is in the process of being removed. (See use of cache in FxVolume::flush_all_files.)

pub fn get_block_size(&self) -> u64

pub async fn is_allocated( &self, start_offset: u64, ) -> Result<(bool, u64), Status>

pub async fn write_at_uncached( &self, offset: u64, content: &[u8], ) -> Result<u64, Status>

pub async fn read_at_uncached( &self, offset: u64, buffer: &mut [u8], ) -> Result<u64, Status>

pub fn get_size_uncached(&self) -> u64

pub fn force_clean(&self)

Forcibly marks the file as clean.