pub struct BlobMappingSession { /* private fields */ }Expand description
BlobMappingSession services requests to open or close blobs within a BlobDirectory.
Upon opening a blob, the blob’s underlying extents (data and merkle blocks) are retrieved and
then forwarded to client asynchronously via sender. The client provides a session-unique
key for each opened blob, which can also be referenced during a Close request.
Implementations
Sourceimpl BlobMappingSession
impl BlobMappingSession
pub fn new( blob_directory: Arc<BlobDirectory>, sender: AsyncSender<RawMappingCommand>, ) -> Self
pub async fn handle_mapping_session_requests( self, stream: MappingSessionRequestStream, )