pub struct BlobMappingServer { /* private fields */ }Expand description
This maintains state for mappings between the driver paging system and Fxfs.
Note: It is the responsibility of the client to track concurrent attempts to open files and broker them properly.
Implementations
Sourceimpl BlobMappingServer
impl BlobMappingServer
pub fn new(blob_directory: Arc<BlobDirectory>) -> Result<Self, Error>
Sourcepub async fn clone_mapping(&self) -> Result<Vmo, Status>
pub async fn clone_mapping(&self) -> Result<Vmo, Status>
Returns a duplicated handle to the mapping VMO.
Sourcepub async fn create_session(&self, hash: Hash) -> Result<SessionState, Error>
pub async fn create_session(&self, hash: Hash) -> Result<SessionState, Error>
Retrieves the extent mappings for the blob and registers a new mapping session. Returns a