pub struct BlobDirectory { /* private fields */ }Expand description
A flat directory containing content-addressable blobs (names are their hashes). It is not possible to create sub-directories. It is not possible to write to an existing blob. It is not possible to open or read a blob until it is written and verified.
Implementations
Sourceimpl BlobDirectory
impl BlobDirectory
Sourceimpl BlobDirectory
impl BlobDirectory
Sourcepub async fn get_blob_vmo(self: &Arc<Self>, hash: Hash) -> Result<Vmo, Error>
pub async fn get_blob_vmo(self: &Arc<Self>, hash: Hash) -> Result<Vmo, Error>
Get a pager-backed VMO for the blob identified by hash in this BlobDirectory. The blob
cannot be purged until all VMOs returned by this function are destroyed.