NodeCache

Struct NodeCache 

pub struct NodeCache(/* private fields */);
NodeCache is an in-memory cache of weak node references.

Implementations

Source

impl NodeCache

pub fn new() -> Self

pub async fn get_or_reserve<'a>(&'a self, object_id: u64) -> GetResult<'a>

Gets a node in the cache, or reserves a placeholder in the cache to fill.

Only the first caller will receive a placeholder result; all callers after that will block until the placeholder is filled (or the placeholder is dropped, at which point the next caller would get a placeholder). Callers that receive a placeholder should later commit a node with NodeCache::commit.

pub fn remove(&self, node: &dyn FxNode)

Removes a node from the cache. Calling this on a placeholder is an error; instead, the placeholder should simply be dropped.

pub fn get(&self, object_id: u64) -> Option<Arc<dyn FxNode>>

Returns the given node if present in the cache. This call should be handled with care. If it is being used to check if there is no live node version, then there should be precautions taken to ensure one will not be created in a race with this call or any of the resulting actions.

pub fn files(&self) -> FileIter<'_>

Returns an iterator over all files in the cache.

pub fn terminate(&self)