pub struct OpenedNode<N: FxNode + ?Sized>(pub Arc<N>);Tuple Fields
0: Arc<N>Implementations
Sourceimpl OpenedNode<FxBlob>
impl OpenedNode<FxBlob>
Sourcepub fn create_child_vmo(&self) -> Result<Vmo, Status>
pub fn create_child_vmo(&self) -> Result<Vmo, Status>
Creates a read-only child VMO for this blob backed by the pager. The blob cannot be purged until all child VMOs have been destroyed.
WARNING: We need to ensure the open count is non-zero before invoking this function, so
it is only implemented for OpenedNode<FxBlob>. This prevents the blob from being purged
before we get a chance to register it with the pager for zx::Signals::VMO_ZERO_CHILDREN.
Sourceimpl<N: FxNode + ?Sized> OpenedNode<N>
impl<N: FxNode + ?Sized> OpenedNode<N>