PagerPacketReceiver

Struct PagerPacketReceiver 

pub struct PagerPacketReceiver<T> { /* private fields */ }
A fuchsia_async::PacketReceiver that handles pager packets and the VMO_ZERO_CHILDREN signal.

Implementations

Source

impl<T: PagerBacked> PagerPacketReceiver<T>

pub fn stop_watching_for_zero_children(&self)

Drops the strong reference to the file that might be held if Pager::watch_for_zero_children was called. This should only be used when forcibly dropping the file object. Calls on_zero_children if the strong reference was held.

pub fn set_receiver( &self, new_receiver: &Arc<T>, ) -> PagerPacketReceiverLock<'_, T>

Sets the current receiver and returns the lock guard so that it can be held after the value is set. Currently this allows synchronizing open count adjustments.