PagerRange

Struct PagerRange 

pub struct PagerRange<T: PagerBacked, U: PagerRequestType> { /* private fields */ }
The requested range from a pager packet. This object ensures that all pager requests receive a response.

Implementations

Source

impl<T: PagerBacked> PagerRange<T, PageInRequest>

pub fn new( range: Range<u64>, file: Arc<T>, epoch_guard: EpochGuard<'static>, ) -> Self

Constructs a new PageInRange<T>. range must be page aligned.

pub fn supply_pages(self, transfer_vmo: &Vmo, transfer_offset: u64)

Supplies pages to the kernel for this range. See zx_pager_supply_pages for more information.

Source

impl<T: PagerBacked> PagerRange<T, MarkDirtyRequest>

pub fn new(range: Range<u64>, file: Arc<T>) -> Self

Constructs a new MarkDirtyRange<T>. range must be page aligned.

pub fn dirty_pages(self)

Allows the kernel to dirty this range of pages. See ZX_PAGER_OP_DIRTY for more information.

Source

impl<T: PagerBacked, U: PagerRequestType> PagerRange<T, U>

pub fn split(self, split_point: u64) -> (Option<Self>, Option<Self>)

Splits the underlying range allowing for different parts of the range to be handled and responded to independently. See RangeExt::split for how splitting a range works. split_point must be page aligned.

pub fn expand(self, new_range: Range<u64>) -> Self

Increases the size of the range that will be responded to. Panics if the current range is not a subset of new_range. new_range must be page aligned.

pub fn chunks(self, chunk_size: u64) -> PagerRangeChunksIter<T, U>

Returns an iterator that splits the range into ranges of chunk_size. If the length of the range is not a multiple of chunk_size then the last chunk won’t be of length chunk_size. The returned iterator will panic if it’s dropped without being fully consumed. chunk_size must a multiple of the page size.

pub fn start(&self) -> u64

pub fn end(&self) -> u64

pub fn len(&self) -> u64

pub fn range(&self) -> Range<u64>

pub fn report_failure(self, status: Status)

Notifies the kernel that the page request for this range has failed. See ZX_PAGER_OP_FAIL for more information.