MarkDirtyRange

Type Alias MarkDirtyRange 

pub type MarkDirtyRange<T> = PagerRange<T, MarkDirtyRequest>;
The requested range from a ZX_PAGER_VMO_DIRTY packet. This object must not be dropped without calling either mark_dirty or report_failure.

Aliased Type

pub struct MarkDirtyRange<T> { /* private fields */ }

Implementations

Source

impl<T: PagerBacked> MarkDirtyRange<T>

pub fn new(range: Range<u64>, file: Arc<T>) -> Self

Constructs a new MarkDirtyRange<T>. range must be page aligned.

pub fn dirty_pages(self)

Allows the kernel to dirty this range of pages. See ZX_PAGER_OP_DIRTY for more information.