AttributeRecordingHandle

Struct AttributeRecordingHandle 

pub struct AttributeRecordingHandle { /* private fields */ }
A handle for storing the profile as an attribute to associate it with an object and tie it to that object’s lifetime.

Implementations

Source

impl AttributeRecordingHandle

pub async fn new(object_id: u64, volume: Arc<FxVolume>) -> Result<Self, Error>

Create the profile handle to be stored as an attribute on the object to keep thehe profile associated with the object and tie the profile lifetime to the object as well.

pub async fn commit_impl(&self) -> Result<(), Error>