pub struct MemoryPressureLevelConfig {
pub background_task_period: Duration,
pub cache_size_limit: usize,
pub background_task_initial_delay: Duration,
}Fields
background_task_period: DurationThe period to wait between flushes, as well as perform other background maintenance tasks (e.g. purging caches).
cache_size_limit: usizeThe limit of cached nodes.
background_task_initial_delay: DurationThe initial delay before the background task runs. The background task has a longer initial delay to avoid running the task during boot.