pub struct FxDirectory { /* private fields */ }Implementations
Sourceimpl FxDirectory
impl FxDirectory
pub fn directory(&self) -> &Directory<FxVolume>
pub fn volume(&self) -> &Arc<FxVolume>
pub fn store(&self) -> &ObjectStore
pub fn is_deleted(&self) -> bool
pub fn set_deleted(&self)
Sourcepub fn check_fscrypt_hard_link_conditions(
&self,
source_wrapping_key_id: Option<WrappingKeyId>,
) -> Result<(), Status>
pub fn check_fscrypt_hard_link_conditions( &self, source_wrapping_key_id: Option<WrappingKeyId>, ) -> Result<(), Status>
As per fscrypt, a user cannot link an unencrypted file into an encrypted directory nor can a user link an encrypted file into a directory encrypted with a different key. Appropriate locks must be held by the caller.