pub trait Recorder: Send + Sync {
// Required methods
fn record(
&mut self,
node: Arc<dyn FxNode>,
offset: u64,
) -> Result<(), Error>;
fn record_open(&mut self, node: Arc<dyn FxNode>) -> Result<(), Error>;
}Expand description
Takes messages to be written into the current profile. This should be dropped before the recording is stopped to ensure that all messages have been flushed to the writer thread.