MemoryPressureLevelConfig

Struct MemoryPressureLevelConfig 

pub struct MemoryPressureLevelConfig {
    pub background_task_period: Duration,
    pub cache_size_limit: usize,
    pub background_task_initial_delay: Duration,
    pub read_ahead_size: u64,
}

Fields

background_task_period: Duration

The period to wait between flushes, as well as perform other background maintenance tasks (e.g. purging caches).

cache_size_limit: usize

The limit of cached nodes.

background_task_initial_delay: Duration

The initial delay before the background task runs. The background task has a longer initial delay to avoid running the task during boot.

read_ahead_size: u64

The amount of read-ahead to do. The read-ahead size is reduce when under memory pressure. The kernel starts evicting pages when under memory pressure so over supplied pages are less likely to be used before being evicted.